Module double_mapped_buffer

Module double_mapped_buffer 

Underlying data structure that maps a buffer twice into virtual memory.

Structs

DoubleMappedBuffer
A buffer that is mapped twice, back-to-back in the virtual address space of the process.

Enums

DoubleMappedBufferError
Errors that can occur when setting up the double mapping.

Functions

pagesizeUnix
Size of virtual memory pages.