Module generic

Module generic 

Available on crate feature generic only.
Circular Buffer with generic Notifier to implement custom wait/block behavior.

Re-exports

pub use crate::Metadata;
pub use crate::NoMetadata;
pub use crate::Notifier;

Structs

Circular
Gerneric Circular Buffer Constructor
Reader
Reader for a generic circular buffer with items of type T and Notifier of type N.
Writer
Writer for a generic circular buffer with items of type T and Notifier of type N.

Enums

CircularError
Error setting up the underlying buffer.