Writer

Struct Writer 

pub struct Writer<T> { /* private fields */ }
Available on crate feature nonblocking only.
Writer for a non-blocking circular buffer with items of type T.

Implementations

Source

impl<T> Writer<T>

pub fn add_reader(&self) -> Reader<T>

Add a reader to the buffer.

All readers can block the buffer, i.e., the writer will only overwrite data, if data was consumeed by all readers.

pub fn try_slice(&mut self) -> &mut [T]

Get a slice to the free slots, available for writing.

This function return immediately. The slice might be empty.

pub fn produce(&mut self, n: usize)

Indicates that n items were written to the output buffer.

It is ok if n is zero.

Panics

If produced more than space was available in the last provided slice.