pub struct Reader<T> { /* private fields */ }Available on crate feature
sync only.Expand description
Reader for a blocking circular buffer with items of type T.
Implementations
Sourceimpl<T> Reader<T>
impl<T> Reader<T>
Sourcepub fn slice(&mut self) -> Option<&[T]>
pub fn slice(&mut self) -> Option<&[T]>
Blocks until there is data to read or until the writer is dropped.
If all data is read and the writer is dropped, all following calls will
return None. If Some is returned, the contained slice is never empty.