Underlying data structure that maps a buffer twice into virtual memory.
Structs
- Double
Mapped Buffer - A buffer that is mapped twice, back-to-back in the virtual address space of the process.
Enums
- Double
Mapped Buffer Error - Errors that can occur when setting up the double mapping.
Functions
- pagesize
Unix - Size of virtual memory pages.