Available on crate feature
generic only.Expand description
Circular Buffer with generic Notifier to implement custom wait/block behavior.
Re-exports
pub use crate::Metadata;pub use crate::NoMetadata;pub use crate::Notifier;
Structs
- Circular
- Gerneric Circular Buffer Constructor
- Reader
- Reader for a generic circular buffer with items of type
Tand Notifier of typeN. - Writer
- Writer for a generic circular buffer with items of type
Tand Notifier of typeN.
Enums
- Circular
Error - Error setting up the underlying buffer.